use crate::request::assets::DataResponse;
use rocket::{Build, get, routes};

#[get("/assets/htmx.min.js")]
pub fn htmx_script_route() -> DataResponse {
    DataResponse::new(
        include_str!("htmx.min.js").as_bytes().to_vec(),
        "application/javascript".to_string(),
        Some(60 * 60 * 24 * 3),
    )
}

#[get("/assets/flowbite.min.css")]
pub fn flowbite_css() -> DataResponse {
    DataResponse::new(
        include_str!("flowbite.min.css").as_bytes().to_vec(),
        "text/css".to_string(),
        Some(60 * 60 * 24 * 3),
    )
}

#[get("/assets/flowbite.min.js")]
pub fn flowbite_js() -> DataResponse {
    DataResponse::new(
        include_str!("flowbite.min.js").as_bytes().to_vec(),
        "application/javascript".to_string(),
        Some(60 * 60 * 24 * 3),
    )
}

#[get("/assets/material.css")]
pub fn material_css() -> DataResponse {
    DataResponse::new(
        include_str!("material.css").as_bytes().to_vec(),
        "text/css".to_string(),
        Some(60 * 60 * 24 * 3),
    )
}

#[get("/assets/material.woff2")]
pub fn material_font() -> DataResponse {
    DataResponse::new(
        include_bytes!("material.woff2").to_vec(),
        "font/woff2".to_string(),
        Some(60 * 60 * 24 * 3),
    )
}

pub trait AssetRoutes {
    fn mount_assets(self) -> Self;
}

impl AssetRoutes for rocket::Rocket<Build> {
    fn mount_assets(self) -> Self {
        self.mount(
            "/",
            routes![
                crate::asset::htmx_script_route,
                crate::asset::flowbite_css,
                crate::asset::flowbite_js,
                crate::asset::material_css,
                crate::asset::material_font
            ],
        )
    }
}
