use crate::ui::UIWidget;
use maud::{Markup, Render, html};

pub struct Visibility(Box<dyn UIWidget>, String);

impl Visibility {
    pub fn visible<T: UIWidget + 'static>(inner: T) -> Self {
        Self(Box::new(inner), "visible".to_string())
    }

    pub fn hidden<T: UIWidget + 'static>(inner: T) -> Self {
        Self(Box::new(inner), "invisible".to_string())
    }

    pub fn collapsed<T: UIWidget + 'static>(inner: T) -> Self {
        Self(Box::new(inner), "collapse".to_string())
    }
}

impl Render for Visibility {
    fn render(&self) -> Markup {
        self.render_with_class("")
    }
}

impl UIWidget for Visibility {
    fn can_inherit(&self) -> bool {
        true
    }

    fn base_class(&self) -> Vec<String> {
        vec![self.1.clone()]
    }

    fn extended_class(&self) -> Vec<String> {
        let mut c = self.base_class();
        c.extend_from_slice(&self.0.extended_class());
        c
    }

    fn render_with_class(&self, class: &str) -> Markup {
        if self.0.as_ref().can_inherit() {
            self.0
                .as_ref()
                .render_with_class(&format!("{} {class}", self.base_class().join(" ")))
        } else {
            html! {
                div class=(format!("{} {class}", self.base_class().join(" "))) {
                    (self.0.as_ref())
                }
            }
        }
    }
}
